@@ -1,7 +1,7 @@
 /*
  Emacs: -*- mode: c++; c-basic-offset: 4; -*-
 
- $Id: arkwidget.cpp,v 1.31.2.1 2003/01/13 10:32:43 helio Exp $
+ $Id: arkwidget.cpp,v 1.31.2.2 2003/05/01 14:39:54 robbers Exp $
 
  ark -- archiver for the KDE project
 
@@ -1878,6 +1878,8 @@ ArkWidget::openArchive( const QString & _filename )
     connect( newArch, SIGNAL(sigExtract(bool)), this, SLOT(slotExtractDone()));
 
     disableAll();
+    archiveContent->setUpdatesEnabled( false );
+    arch = newArch;
     newArch->open();
 }
 
