@@ -1,7 +1,7 @@
 //  -*-C++-*-           emacs magic for .h files
 /*
 
- $Id: extractdlg.h,v 1.22 2002/02/10 14:06:23 mlaurent Exp $
+ $Id: extractdlg.h,v 1.24.2.1 2003/01/13 10:32:44 helio Exp $
 
  ark -- archiver for the KDE project
 
@@ -33,6 +33,7 @@
 #define __EXTRACTDLG_H__
 
 #include <qradiobutton.h>
+#include <kurl.h>
 
 #include "arch.h"
 
@@ -46,6 +47,7 @@ class KDialogBase;
 class KHistoryCombo;
 class KCompletion;
 class KURLCompletion;
+class KURLRequester;
 
 class ArkSettings;
 
@@ -58,10 +60,11 @@ public:
   ~ExtractDlg();
   enum ExtractOp{ All, Selected, Current, Pattern };
   int extractOp();
+  KURL extractDir();
   void disableSelectedFilesOption();
   void disableCurrentFileOption() { m_radioCurrent->setEnabled(false); }
 public slots:
-  void browse();
+  //void browse();
   void choosePattern() { m_radioPattern->setChecked(true); }
   void openPrefs();
   void accept();
@@ -75,7 +78,9 @@ private: // data
   QRadioButton *m_radioCurrent, *m_radioAll, *m_radioSelected, *m_radioPattern;
   QLineEdit *m_patternLE;
   KHistoryCombo *m_extractDirCB;
+  KURLRequester *m_urlRequester;
   ArkSettings *m_settings;
+  KURL m_extractDir;
 };
 
 // this class is used for displaying the filenames that were not
