@@ -1,15 +1,16 @@
 /*
   -*- mode: c++; c-basic-offset: 4; indent-tabs-mode: nil -*-
 
-$Id: main.cpp,v 1.6.2.3 2002/06/13 00:29:01 helio Exp $
+$Id: main.cpp,v 1.9.2.1 2003/01/13 10:32:44 helio Exp $
 
 ark: A program for modifying archives via a GUI.
 
 Copyright (C)
-1997-1999 Robert Palmbos <palm9744@kettering.edu>
-1999 Francois-Xavier Duranceau <duranceau@kde.org>
-1999-2000: Corel Corporation (author: Emily Ezust  emilye@corel.com)
+2002: Helio Chissini de Castro <helio@conectiva.com.br>
 2001: Roberto Selbach Teixeira <maragato@kde.org>
+1999-2000: Corel Corporation (author: Emily Ezust  emilye@corel.com)
+1999 Francois-Xavier Duranceau <duranceau@kde.org>
+1997-1999 Robert Palmbos <palm9744@kettering.edu>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -35,24 +36,18 @@ Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
 // C includes
-#include <sys/param.h>
-#include <stdio.h>
 #include <stdlib.h>
 
 // QT includes
 
 // KDE includes
-#include <klocale.h>
 #include <kdebug.h>
 #include <dcopclient.h>
 #include <kcmdlineargs.h>
 #include <kaboutdata.h>
-#include <kio/job.h>
-#include <kmainwindow.h>
 
 // ark includes
 #include "arkapp.h"
-#include "arkwidget.h"
 
 static KCmdLineOptions option[] =
 {
@@ -63,39 +58,47 @@ static KCmdLineOptions option[] =
 
 int main( int argc, char *argv[]  )
 {
-    KAboutData aboutData( "ark", I18N_NOOP( "Ark" ),
-                          "v2.1.9", I18N_NOOP("KDE Archiving tool"), 
-			  KAboutData::License_GPL,
-                          I18N_NOOP( "(c) 1997-2001, The Various Ark Developers" ) );
-    aboutData.addAuthor( "Roberto Teixeira", I18N_NOOP( "Current maintainer" ),
-                         "maragato@kde.org" );
-    aboutData.addAuthor( "Helio Chissini de Castro", I18N_NOOP( "Current maintainer" ),
-		         "helio@conectiva.com.br" );
-    aboutData.addAuthor( "Francois-Xavier Duranceau", 0, "duranceau@kde.org" );
-    aboutData.addAuthor( "Emily Ezust (Corel Corporation)", 0, "emilye@corel.com" );
-    aboutData.addAuthor( "Michael Jarrett (Corel Corporation)", 0,
-                         "michaelj@corel.com" );
-    aboutData.addAuthor( "Robert Palmbos", 0, "palm9744@kettering.edu" );
-
-
-    KCmdLineArgs::init( argc, argv, &aboutData );
-    KCmdLineArgs::addCmdLineOptions( option );
-
-    kdDebug( 1601 ) << "Starting ark. argc=" << argc << "  First arg: " << (argc == 2 ? argv[1] : 0) << endl;
-
-    if ( !ArkApplication::start() )
-    {
-        // Already running!
-        kdDebug( 1601 ) << "Already running" << endl;
-        exit( 0 );
-    }
-
-    if ( ArkApplication::getInstance()->isRestored() )
-    {
-        kdDebug( 1601 ) << "In main: Restore..." << endl;
-        RESTORE( ArkWidget );
-    }
-    kdDebug( 1601 ) << "Starting ark..." << endl;
-
-    return ArkApplication::getInstance()->exec();
+	KAboutData aboutData( "ark", I18N_NOOP( "Ark" ),
+			"v2.1.9", I18N_NOOP("KDE Archiving tool"), 
+			KAboutData::License_GPL,
+			I18N_NOOP( "(c) 1997-2002, The Various Ark Developers" ) );
+	
+	aboutData.addAuthor( "Helio Chissini de Castro", I18N_NOOP( "Current maintainer" ),
+			"helio@conectiva.com.br" );
+	
+	aboutData.addAuthor( "Roberto Teixeira", 0,
+			"maragato@conectiva.com" );
+	
+	aboutData.addAuthor( "Francois-Xavier Duranceau", 0, "duranceau@kde.org" );
+	
+	aboutData.addAuthor( "Emily Ezust (Corel Corporation)", 0, "emilye@corel.com" );
+	
+	aboutData.addAuthor( "Michael Jarrett (Corel Corporation)", 0,
+			"michaelj@corel.com" );
+	
+	aboutData.addAuthor( "Robert Palmbos", 0, "palm9744@kettering.edu" );
+	
+	KCmdLineArgs::init( argc, argv, &aboutData );
+	KCmdLineArgs::addCmdLineOptions( option );
+	
+	kdDebug( 1601 ) << "Starting ark. argc=" << argc << "  First arg: " << (argc == 2 ? argv[1] : 0) << endl;
+    if( argc > 2 )
+        for( int c = 1; c<argc; c++ )
+            kdDebug( 1601 ) << "arg[" << c << "] " << argv[ c ] << endl;
+	
+	if ( !ArkApplication::start() )
+	{
+		// Already running!
+		kdDebug( 1601 ) << "Already running" << endl;
+		exit( 0 );
+	}
+	
+	if ( ArkApplication::getInstance()->isRestored() )
+	{
+		kdDebug( 1601 ) << "In main: Restore..." << endl;
+		RESTORE( ArkTopLevelWindow );
+	}
+	kdDebug( 1601 ) << "Starting ark..." << endl;
+	
+	return ArkApplication::getInstance()->exec();
 }
