@@ -1,7 +1,7 @@
 //  -*-C++-*-           emacs magic for .h files
 /*
 
- $Id: rar.h,v 1.8 2001/02/07 20:53:47 mjarrett Exp $
+ $Id: rar.h,v 1.9.6.1 2003/01/13 10:32:44 helio Exp $
 
  ark -- archiver for the KDE project
 
@@ -27,17 +27,18 @@
 #ifndef __RAR_H__
 #define __RAR_H__ 
 
-// Qt includes
-#include <qstring.h>
-#include <qstrlist.h>
+class QString;
+class QStringList;
 
-#include "arch.h"
+class Arch;
+class ArkSettings;
+class ArkSettingsBase;
 
-class RarArch : public Arch 
+class RarArch : public Arch
 {
   Q_OBJECT
 public:
-  RarArch( ArkSettings *_settings, Viewer *_gui,
+  RarArch( ArkSettings *_settings, ArkWidgetBase *_gui,
 	   const QString & _fileName );
   virtual ~RarArch() {}
   virtual void open();
