@@ -1,6 +1,6 @@
 /*
 
- $Id: zoo.cpp,v 1.1.2.1 2002/06/13 00:29:01 helio Exp $
+ $Id: zoo.cpp,v 1.2.2.4 2003/01/13 10:32:44 helio Exp $
 
  ark -- archiver for the KDE project
 
@@ -25,6 +25,8 @@
 
 */
 
+#include <config.h>
+
 #include <stdio.h>
 #include <unistd.h>
 #include <stdlib.h>
@@ -33,6 +35,7 @@
 
 // QT includes
 #include <qfile.h>
+#include <qdir.h>
 
 // KDE includes
 #include <kdebug.h>
@@ -45,7 +48,7 @@
 #include "arksettings.h"
 #include "arch.h"
 #include "zoo.h"
-
+#include "arkutils.h"
 
 QString fixTime(const QString &_strTime);
 
@@ -69,29 +72,29 @@ bool ZooArch::processLine(const QCString &line)
 
   // Note: I'm reversing the ratio and the length for better display
 
-  sscanf(_line, " %[0-9] %[0-9%] %[0-9] %[0-9] %[a-zA-Z] %[0-9]%[ ]%11[ 0-9:+-]%2[C ]%[^\n]",
+  sscanf(_line, " %79[0-9] %79[0-9%] %79[0-9] %79[0-9] %79[a-zA-Z] %79[0-9]%79[ ]%11[ 0-9:+-]%2[C ]%4095[^\n]",
 	 columns[1], columns[0], columns[2], columns[3], columns[7],
 	 columns[8], columns[9], columns[4], columns[10], filename);
 
 
   kdDebug(1601) << "The actual file is " << (const char *)filename << endl;
 
-  QString year = Utils::fixYear(columns[8]);
+  QString year = ArkUtils::fixYear(columns[8]);
 
   kdDebug(1601) << "The year is " << year << endl;
 
   QString strDate;
   strDate.sprintf("%s-%.2d-%.2d", year.utf8().data(),
-		    Utils::getMonth(columns[7]), atoi(columns[3]));
+		    ArkUtils::getMonth(columns[7]), atoi(columns[3]));
 
-  strcpy(columns[3], strDate.ascii());
+  strlcpy(columns[3], strDate.ascii(), sizeof(columns[3]));
   kdDebug(1601) << "New timestamp is " << columns[3] << endl;
 
-  strcat(columns[3], " ");
-  strcat(columns[3], fixTime(columns[4]).ascii());
+  strlcat(columns[3], " ", sizeof(columns[3]));
+  strlcat(columns[3], fixTime(columns[4]).ascii(),sizeof(columns[3]));
 
   QStringList list;
-  list.append(QString::fromLocal8Bit(filename));
+  list.append(QFile::decodeName(filename));
   for (int i=0; i<4; i++)
     {
       list.append(QString::fromLocal8Bit(columns[i]));
@@ -112,7 +115,7 @@ void ZooArch::open()
 
 
   KProcess *kp = new KProcess;
-  *kp << m_archiver_program << "l" << m_filename.local8Bit();
+  *kp << m_archiver_program << "l" << m_filename;
   connect( kp, SIGNAL(receivedStdout(KProcess*, char*, int)),
 	   this, SLOT(slotReceivedTOC(KProcess*, char*, int)));
   connect( kp, SIGNAL(receivedStderr(KProcess*, char*, int)),
@@ -182,7 +185,7 @@ void ZooArch::addFile( QStringList *urls )
   else
     *kp << "-add";
 
-  *kp << m_filename.local8Bit() ;
+  *kp << m_filename;
 
   QString base;
   QString url;
@@ -205,7 +208,7 @@ void ZooArch::addFile( QStringList *urls )
       pos = file.findRev( '/' );
       base = file.left( pos );
       pos++;
-      chdir( QFile::encodeName(base) );
+      QDir::setCurrent(base);
       base = file.right( file.length()-pos );
       file = base;
     }
@@ -247,9 +250,9 @@ void ZooArch::unarchFile(QStringList *_fileList, const QString & _destDir,
   // zoo has no option to specify the destination directory
   // so I have to change to it.
 
-  int ret = chdir(QFile::encodeName(dest));
+  bool ret = QDir::setCurrent(dest);
  // I already checked the validity of the dir before coming here
-  Q_ASSERT(ret == 0); 
+  Q_ASSERT(ret);
 
 
   QString tmp;
@@ -272,7 +275,7 @@ void ZooArch::unarchFile(QStringList *_fileList, const QString & _destDir,
       for ( QStringList::Iterator it = _fileList->begin();
 	    it != _fileList->end(); ++it ) 
 	{
-	  *kp << (*it).local8Bit();/*.latin1() ;*/
+	  *kp << (*it);/*.latin1() ;*/
 	}
     }
  
@@ -302,12 +305,12 @@ void ZooArch::remove(QStringList *list)
   KProcess *kp = new KProcess;
   kp->clearArguments();
   
-  *kp << m_archiver_program << "D" << m_filename.local8Bit();
+  *kp << m_archiver_program << "D" << m_filename;
   for ( QStringList::Iterator it = list->begin();
 	it != list->end(); ++it )
     {
       QString str = *it;
-      *kp << str.local8Bit();
+      *kp << str;
     }
 
   connect( kp, SIGNAL(receivedStdout(KProcess*, char*, int)),
