@@ -1,13 +1,14 @@
 //  -*-C++-*-           emacs magic for .h files
 /*
 
- $Id: zoo.h,v 1.7 2001/02/07 20:53:47 mjarrett Exp $
+ $Id: zoo.h,v 1.8.6.1 2003/01/13 10:32:44 helio Exp $
 
  ark -- archiver for the KDE project
 
  Copyright (C)
 
  2000: Corel Corporation (author: Emily Ezust, emilye@corel.com)
+ 2001: Corel Corporation (author: Michael Jarrett, michaelj@corel.com)
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
@@ -27,17 +28,19 @@
 #ifndef __ZOO_H__
 #define __ZOO_H__ 
 
-// Qt includes
-#include <qstring.h>
-#include <qstrlist.h>
+class QString;
+class QCString;
+class QStringList;
 
-#include "arch.h"
+class Arch;
+class ArkSettings;
+class ArkWidgetBase;
 
-class ZooArch : public Arch 
+class ZooArch : public Arch
 {
   Q_OBJECT
 public:
-  ZooArch( ArkSettings *_settings, Viewer *_gui,
+  ZooArch( ArkSettings *_settings, ArkWidgetBase *_gui,
 	   const QString & _fileName );
   virtual ~ZooArch() { }
 	
@@ -53,7 +56,7 @@ public:
 
 protected slots:
   virtual bool processLine(const QCString &line);
-
+	
 private:
   void initExtract( bool, bool, bool );
   void setHeaders();
