@@ -1,5 +1,5 @@
 /*
-    $Id: kcalc.cpp,v 1.75.2.3 2003/03/02 21:33:31 zumstein Exp $
+    $Id: kcalc.cpp,v 1.75.2.6 2003/07/15 00:08:34 mueller Exp $
 
     kCalculator, a simple scientific calculator for KDE
 
@@ -84,14 +84,17 @@ extern bool				display_error;
 // Name: QtCalculator(QWidget *parent, const char *name)
 //-------------------------------------------------------------------------
 QtCalculator::QtCalculator(QWidget *parent, const char *name)
-	: KMainWindow(parent, name), inverse(false), hyp_mode(false), eestate(false), 
-	refresh_display(false), display_size(DEC_SIZE),  angle_mode(ANG_DEGREE), 
+	: KMainWindow(parent, name), inverse(false), hyp_mode(false), eestate(false),
+	refresh_display(false), display_size(DEC_SIZE),  angle_mode(ANG_DEGREE),
 	input_limit(0), input_count(0), decimal_point(0), precedence_base(0),
-	current_base(NB_DECIMAL), memory_num(0.0), last_input(DIGIT), 
+	current_base(NB_DECIMAL), memory_num(0.0), last_input(DIGIT),
 	history_index(0), selection_timer(new QTimer), key_pressed(false),
 	mInternalSpacing(4), status_timer(new QTimer), mConfigureDialog(0)
 {
-	// make sure the display_str is NULL terminated so we can
+	/* central widget to contain all the elements */
+	QWidget *central = new QWidget(this);
+	setCentralWidget(central);
+    // make sure the display_str is NULL terminated so we can
 	// user library string functions
 	display_str[0] = '\0';
 
@@ -107,26 +110,26 @@ QtCalculator::QtCalculator(QWidget *parent, const char *name)
 	connect(kapp,SIGNAL(kdisplayPaletteChanged()), this, SLOT(set_colors()));
 
 	// Accelerators to exit the program
-	QAccel *accel = new QAccel(this);
+	QAccel *accel = new QAccel(central);
 	accel->connectItem(accel->insertItem(Key_Q+CTRL), this, SLOT(quitCalc()));
 	accel->connectItem(accel->insertItem(Key_X+CTRL), this, SLOT(quitCalc()));
 
 	// Create uppermost bar with buttons and numberdisplay
 	mConfigButton = new KPushButton(KGuiItem( i18n("Config&ure"), "configure" ),
-            this, "configbutton");
+            central, "configbutton");
 	mConfigButton->setAutoDefault(false);
 	QToolTip::add(mConfigButton, i18n("Click to configure KCalc"));
 	connect(mConfigButton, SIGNAL(clicked()), this, SLOT(configclicked()));
 	if (KGlobal::config()->isImmutable())
 	   mConfigButton->hide();
 
-	mHelpMenu = new KHelpMenu(this, KGlobal::instance()->aboutData());
+	mHelpMenu = new KHelpMenu(central, KGlobal::instance()->aboutData());
 
-	mHelpButton = new KPushButton(KStdGuiItem::help(), this);
+	mHelpButton = new KPushButton(KStdGuiItem::help(), central);
 	mHelpButton->setAutoDefault(false);
 	mHelpButton->setPopup(mHelpMenu->menu());
 
-	calc_display = new DLabel(this, "display");
+	calc_display = new DLabel(central, "display");
 	calc_display->setFrameStyle(QFrame::WinPanel | QFrame::Sunken);
 	calc_display->setAlignment(AlignRight | AlignVCenter);
 	calc_display->setFocus();
@@ -135,24 +138,24 @@ QtCalculator::QtCalculator(QWidget *parent, const char *name)
 	connect(calc_display, SIGNAL(clicked()), this, SLOT(display_selected()));
 
 	// Status bar contents
-	statusINVLabel = new QLabel( this, "INV" );
+	statusINVLabel = new QLabel( central, "INV" );
 	Q_CHECK_PTR(statusINVLabel);
 	statusINVLabel->setFrameStyle(QFrame::Panel | QFrame::Sunken);
 	statusINVLabel->setAlignment(AlignCenter);
 	statusINVLabel->setText("NORM");
 
-	statusHYPLabel = new QLabel(this, "HYP");
+	statusHYPLabel = new QLabel(central, "HYP");
 	Q_CHECK_PTR(statusHYPLabel);
 	statusHYPLabel->setFrameStyle(QFrame::Panel | QFrame::Sunken);
 	statusHYPLabel->setAlignment(AlignCenter);
 
-	statusERRORLabel = new QLabel(this, "ERROR");
+	statusERRORLabel = new QLabel(central, "ERROR");
 	Q_CHECK_PTR(statusERRORLabel);
 	statusERRORLabel->setFrameStyle(QFrame::Panel | QFrame::Sunken);
 	statusERRORLabel->setAlignment(AlignLeft|AlignVCenter);
 
 	// Create Number Base Button Group
-	QButtonGroup *base_group = new QButtonGroup(4, Horizontal,  this, "base");
+	QButtonGroup *base_group = new QButtonGroup(4, Horizontal,  central, "base");
 	base_group->setTitle(i18n("Base"));
 	connect(base_group, SIGNAL(clicked(int)), SLOT(Base_Selected(int)));
 
@@ -182,7 +185,7 @@ QtCalculator::QtCalculator(QWidget *parent, const char *name)
 		this, SLOT(Bin_Selected()));
 
 	// create angle button group
-	angle_group = new QButtonGroup(3, Horizontal, this, "angle");
+	angle_group = new QButtonGroup(3, Horizontal, central, "angle");
 	angle_group->setTitle(i18n( "Angle") );
 	connect( angle_group, SIGNAL(clicked(int)), SLOT(angle_selected(int)));
 
@@ -210,8 +213,8 @@ QtCalculator::QtCalculator(QWidget *parent, const char *name)
 	//
 
 	// First the widgets that are the parents of the buttons
-	mSmallPage = new QWidget(this);
-	mLargePage = new QWidget(this);
+	mSmallPage = new QWidget(central);
+	mLargePage = new QWidget(central);
 
 	pbhyp = new QPushButton("Hyp", mSmallPage, "hypbutton");
 	pbhyp->setAutoDefault(false);
@@ -491,7 +494,7 @@ QtCalculator::QtCalculator(QWidget *parent, const char *name)
 	QHBoxLayout *statusLayout	= new QHBoxLayout();
 
 	// bring them all together
-	QVBoxLayout *mainLayout = new QVBoxLayout(this, mInternalSpacing,
+	QVBoxLayout *mainLayout = new QVBoxLayout(central, mInternalSpacing,
 		mInternalSpacing );
 
 	mainLayout->addLayout(topLayout );
@@ -565,8 +568,8 @@ QtCalculator::QtCalculator(QWidget *parent, const char *name)
 	largeBtnLayout->addWidget(pbminus, 3, 4);
 	largeBtnLayout->addWidget(pbshift, 3, 5);
 
-	largeBtnLayout->addWidget(pbperiod, 4, 0);
-	largeBtnLayout->addWidget(pb0, 4, 1);
+	largeBtnLayout->addWidget(pb0, 4, 0);
+	largeBtnLayout->addWidget(pbperiod, 4, 1);
 	largeBtnLayout->addWidget(pbequal, 4, 2);
 	largeBtnLayout->addWidget(pbpercent, 4, 3);
 	largeBtnLayout->addWidget(pbnegate, 4, 4);
@@ -871,6 +874,7 @@ void QtCalculator::configurationChanged(const DefStruct &state)
 //-------------------------------------------------------------------------
 void QtCalculator::keyPressEvent(QKeyEvent *e)
 {
+    if ( ( e->state() & KeyButtonMask ) == 0 || ( e->state() & ShiftButton ) ) {
 	switch (e->key())
 	{
 	case Key_F1:
@@ -1102,6 +1106,7 @@ void QtCalculator::keyPressEvent(QKeyEvent *e)
 		pbreci->setOn(true);
 		break;
 	}
+    }
 }
 
 //-------------------------------------------------------------------------
@@ -1888,7 +1893,7 @@ void QtCalculator::configclicked()
 	}
 
 	mConfigureDialog->show();
-        mConfigureDialog->setActiveWindow();
+        //mConfigureDialog->setActiveWindow();
         mConfigureDialog->raise();
 }
 
@@ -2026,7 +2031,7 @@ void QtCalculator::writeSettings()
 void QtCalculator::display_selected()
 {
 	if(calc_display->Button() == LeftButton) {
-	
+
 		if(calc_display->isLit()) {
 			QClipboard *cb = QApplication::clipboard();
 			bool oldMode = cb->selectionModeEnabled();
@@ -2324,7 +2329,7 @@ bool QtCalculator::eventFilter(QObject *o, QEvent *e)
 int main(int argc, char *argv[])
 {
         QString precisionStatement;
-        
+
 #ifdef HAVE_LONG_DOUBLE
         precisionStatement = QString(I18N_NOOP("Built with %1 bit (long double) precision"))
                                      .arg(sizeof(long double) * 8);
@@ -2348,7 +2353,7 @@ int main(int argc, char *argv[])
 	aboutData.addAuthor("Bernd Johannes Wuebben", 0, "wuebben@kde.org");
 	aboutData.addAuthor("Evan Teran", 0, "emt3734@rit.edu");
 	aboutData.addAuthor("Espen Sand", 0, "espen@kde.org");
-	aboutData.addAuthor("Chris Howells", 0, "howells@kde.org");	
+	aboutData.addAuthor("Chris Howells", 0, "howells@kde.org");
         aboutData.addAuthor("Aaron J. Seigo", 0, "aseigo@olympusproject.org");
         aboutData.addAuthor("Charles Samuels", 0, "charles@altair.dhs.org");
 	KCmdLineArgs::init(argc, argv, &aboutData);
