@@ -1,5 +1,5 @@
 /*
-    $Id: kcalc.h,v 1.39 2002/09/23 21:25:21 waba Exp $
+    $Id: kcalc.h,v 1.39.2.1 2003/02/15 20:40:23 staikos Exp $
 
     KCalc, a scientific calculator for the X window system using the
     Qt widget libraries, available at no cost at http://www.troll.no
@@ -42,7 +42,7 @@ class ConfigureDialog;
 class DLabel;
 class KPushButton;
 
-#include <kdialog.h>
+#include <kmainwindow.h>
 #include "stats.h"
 
 
@@ -173,7 +173,7 @@ typedef struct _DefStruct
 } DefStruct;
 
 
-class QtCalculator : public KDialog
+class QtCalculator : public KMainWindow
 {
     Q_OBJECT
 
