@@ -1,5 +1,5 @@
 /*
-    $Id: kcalctype.h,v 1.15 2002/02/24 11:20:22 hausmann Exp $
+    $Id: kcalctype.h,v 1.16 2002/08/16 18:16:58 waba Exp $
 
     KCalc, a scientific calculator for the X window system using the
     Qt widget libraries, available at no cost at http://www.troll.no
@@ -30,6 +30,7 @@
 #ifndef KCALC_TYPE_H
 #define KCALC_TYPE_H
 
+#include <limits.h>
 #include <math.h>
 
 // The following for all the poor devels out there who don't have long double math.
@@ -43,7 +44,6 @@
 //#endif
 
 #ifdef HAVE_LONG_DOUBLE
-
 /* should be detected by autoconf and defined in config.h
    Be carefull when modifying these lines. HAVE_LONG_DOUBLE
    is used all over kcalc's sources to determine whether 
@@ -80,6 +80,7 @@
 	#define LOG_TEN(X)	log10l(X)
 	#define SQRT(X)		sqrtl(X)
 	#define ISINF(X)	isinfl(X)
+	#define STRTOD(X,Y)	strtold(X,Y)
 #else
 	#define FABS(X)		fabs(X)
 	#define MODF(X,Y)	modf(X,Y)
@@ -102,6 +103,28 @@
 	#define LOG_TEN(X)	log10(X)
 	#define SQRT(X)		sqrt(X)
 	#define ISINF(X)	isinf(X)
+	#define STRTOD(X,Y)	strtod(X,Y)
 #endif
 
+#undef HAVE_LONG_LONG
+#if defined(LLONG_MAX) && defined(HAVE_LONG_DOUBLE)
+#define KCALC_LONG_MIN	LLONG_MIN
+#define KCALC_LONG_MAX	LLONG_MAX
+#define KCALC_ULONG_MAX	ULLONG_MAX
+#define KCALC_LONG	long long
+#define HAVE_LONG_LONG
+#else
+#if defined(LONG_LONG_MAX) && defined(HAVE_LONG_DOUBLE)
+#define KCALC_LONG_MIN	LONG_LONG_MIN
+#define KCALC_LONG_MAX	LONG_LONG_MAX
+#define KCALC_ULONG_MAX	ULONG_LONG_MAX
+#define KCALC_LONG	long long
+#define HAVE_LONG_LONG
+#else
+#define KCALC_LONG_MIN	LONG_MIN
+#define KCALC_LONG_MAX	LONG_MAX
+#define KCALC_ULONG_MAX	ULONG_MAX
+#define KCALC_LONG	long
+#endif
+#endif
 #endif 
