@@ -25,6 +25,7 @@ class QCheckBox;
 class QLabel;
 class QRadioButton;
 class QSpinBox;
+class KColorButton;
 class KFontChooser;
 
 #include <kdialogbase.h>
@@ -32,55 +33,6 @@ class KFontChooser;
 
 #include "kcalc.h"
 
-
-
-class ColorListBox : public KListBox
-{
-  Q_OBJECT
-
-  public:
-    ColorListBox( QWidget *parent=0, const char * name=0, WFlags f=0 );
-    void setColor( uint index, const QColor &color );
-    const QColor color( uint index );
-
-  public slots:
-    virtual void setEnabled( bool state );
-
-  protected:
-    void dragEnterEvent( QDragEnterEvent *e );
-    void dragLeaveEvent( QDragLeaveEvent *e );
-    void dragMoveEvent( QDragMoveEvent *e );
-    void dropEvent( QDropEvent *e );
-
-  private slots:
-    void newColor( int index );
-
-  private:
-    int mCurrentOnDragEnter;
-
-};
-
-
-class ColorListItem : public QListBoxItem
-{
-  public:
-    ColorListItem( const QString &text, const QColor &color=Qt::black );
-    const QColor &color( void );
-    void  setColor( const QColor &color );
-  
-  protected:
-    virtual void paint( QPainter * );
-    virtual int height( const QListBox * ) const;
-    virtual int width( const QListBox * ) const;
-
-  private:
-    QColor mColor;
-    int mBoxWidth;
-};
-
-
-
-
 class ConfigureDialog : public KDialogBase
 {
 	Q_OBJECT
@@ -92,15 +44,15 @@ public:
 	DefStruct state();
 
 protected slots:
-	virtual void slotOk();
-	virtual void slotApply(); 
-	virtual void slotCancel(); 
+	void slotOk();
+	void slotApply(); 
+	void slotCancel(); 
+    void fixCheckToggled( bool );
 
 private:
 	void setupSettingPage();
 	void setupFontPage();
 	void setupColorPage();
-	void setupAboutPage();
 
 private:
 	QCheckBox    *mFixCheck;
@@ -109,8 +61,15 @@ private:
 	QCheckBox    *mBeepCheck;
 	QRadioButton *mTrigRadio;
 	QRadioButton *mStatRadio;
+    QLabel       *TextLabel2;
 	KFontChooser *mFontChooser;
-	ColorListBox *mColorList; 
+	KColorButton *mColorFGround; 
+    KColorButton *mColorBGround;
+    KColorButton *mColorFunctions;
+    KColorButton *mColorHexa;
+    KColorButton *mColorNumbers;
+    KColorButton *mColorMemory;
+    KColorButton *mColorOperations;
 
 	DefStruct    mState;
 
