@@ -17,18 +17,18 @@
 #include <qstring.h>
 #include <qwidget.h>
 
-#include <kapp.h>
-#include <kbuttonbox.h>
+#include <kapplication.h>
+#include <kpushbutton.h>
 #include <kcharselect.h>
-#include <kdialog.h>
+#include <kmainwindow.h>
 
-static const char *version = "v1.0"; 
+static const char *version = "v1.1"; 
 
 /******************************************************************/
 /* class KCharSelectDia                                           */
 /******************************************************************/
 
-class KCharSelectDia : public KDialog
+class KCharSelectDia : public KMainWindow
 {
   Q_OBJECT
 
@@ -46,13 +46,13 @@ protected:
   QGridLayout *grid;
   KCharSelect *charSelect;
   QLineEdit   *lined;
-  KButtonBox  *bbox1;
-  QPushButton *bClip,*bClear;
-  QPushButton *bHelp;
+  KPushButton *bClip,*bClear;
+  KPushButton *bHelp;
 
   QChar vChr;
   QString vFont;
-  bool  entryDirection;
+  int pointSize;
+  bool entryDirection;
 
 protected slots:
   void charChanged(const QChar &_chr);
@@ -67,8 +67,7 @@ protected slots:
   void fromClipUTF8();
   void flipText();
   void toggleEntryDirection();
-  void lineEditChanged(void);
-  void about();
+  void lineEditChanged();
   void _exit();
   void clear();
   void help();
