@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: passwd.h,v 1.3 2001/10/24 09:02:45 bero Exp $
+ * $Id: passwd.h,v 1.3.4.1 2003/04/22 15:10:38 waba Exp $
  *
  * This file is part of the KDE project, module kdesu.
  * Copyright (C) 2000 Geert Jansen <jansen@kde.org>
@@ -35,7 +35,8 @@ private:
     int ConversePasswd(const char *oldpass, const char *newpass,
 	    int check);
 
-    QCString m_User, m_ThisUser, m_Error;
+    QCString m_User, m_Error;
+    bool bOtherUser;
 };
 
 
