@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: passwddlg.cpp,v 1.5 2002/05/15 07:40:01 adridg Exp $
+ * $Id: passwddlg.cpp,v 1.5.2.1 2003/04/22 15:10:38 waba Exp $
  *
  * This file is part of the KDE project, module kdesu.
  * Copyright (C) 2000 Geert Jansen <jansen@kde.org>
@@ -13,11 +13,9 @@
 #include "passwddlg.h"
 
 
-KDEpasswd1Dialog::KDEpasswd1Dialog(QCString user)
-    : KPasswordDialog(Password, "")
+KDEpasswd1Dialog::KDEpasswd1Dialog()
+    : KPasswordDialog(Password, false, 0)
 {
-    m_User = user;
-
     setCaption(i18n("Change Password"));
     setPrompt(i18n("Please enter your current password."));
 }
@@ -30,22 +28,23 @@ KDEpasswd1Dialog::~KDEpasswd1Dialog()
 
 bool KDEpasswd1Dialog::checkPassword(const char *password)
 {
-    PasswdProcess proc(m_User);
+    PasswdProcess proc(0);
 
     int ret = proc.checkCurrent(password);
     switch (ret)
     {
     case -1:
-	KMessageBox::error(this, i18n("Conversation with `passwd' failed."));
+	KMessageBox::error(this, i18n("Conversation with `passwd' failed.")+"\n"+QString::fromLocal8Bit(proc.error()));
 	done(Rejected);
-	return true;
+	return false;
 
     case 0:
 	return true;
 
     case PasswdProcess::PasswdNotFound:
 	KMessageBox::error(this, i18n("Could not find the program `passwd'."));
-	return true;
+	done(Rejected);
+	return false;
 
     case PasswdProcess::PasswordIncorrect:
         KMessageBox::sorry(this, i18n("Incorrect password! Please try again."));
@@ -54,15 +53,16 @@ bool KDEpasswd1Dialog::checkPassword(const char *password)
     default:
 	KMessageBox::error(this, i18n("Internal error: illegal return value "
 		"from PasswdProcess::checkCurrent."));
-	return true;
+	done(Rejected);
+	return false;
     }
 }
 
 
 // static
-int KDEpasswd1Dialog::getPassword(QCString &password, QCString user)
+int KDEpasswd1Dialog::getPassword(QCString &password)
 {
-    KDEpasswd1Dialog *dlg = new KDEpasswd1Dialog(user);
+    KDEpasswd1Dialog *dlg = new KDEpasswd1Dialog();
     int res = dlg->exec();
     if (res == Accepted)
 	password = dlg->password();
@@ -73,7 +73,7 @@ int KDEpasswd1Dialog::getPassword(QCString &password, QCString user)
 
 
 KDEpasswd2Dialog::KDEpasswd2Dialog(const char *oldpass, QCString user)
-    : KPasswordDialog(NewPassword, "")
+    : KPasswordDialog(NewPassword, false, 0)
 {
     m_Pass = oldpass;
     m_User = user;
