@@ -1,7 +1,7 @@
 /*
  * disklist.cpp
  *
- * $Id: disklist.cpp,v 1.27.2.1 2003/02/12 03:23:42 staikos Exp $
+ * $Id: disklist.cpp,v 1.27.2.2 2003/05/10 21:45:00 waba Exp $
  *
  * Copyright (c) 1999 Michael Kropfberger <michael.kropfberger@gmx.net>
  *
@@ -344,8 +344,7 @@ void DiskList::dfDone()
 
 
       s=s.remove(0,s.find(BLANK)+1 );  // delete the capacity 94%
-      disk->setMountPoint(s.left(s.find(BLANK)) );
-      s=s.remove(0,s.find(BLANK)+1 );
+      disk->setMountPoint(s);
       //kdDebug() << "    MountPoint:       [" << disk->mountPoint() << "]" << endl;
 
       if ( (disk->kBSize() > 0)
