@@ -36,19 +36,12 @@ class KDiskFreeWidget : public KCModule
   
   public:
     KDiskFreeWidget( QWidget *parent=0, const char *name=0 );
-    virtual void load( void );
-    virtual void save( void );
-    virtual void defaults( void );
+    ~KDiskFreeWidget();
 
-  protected:
-    virtual void hideEvent( QHideEvent * );
+    QString quickHelp() const;
 
   private:
-    int pageNumber( void );
-
-  private:
-    QTabWidget *mTab;
-    QFrame *mPage[3];
+    QFrame *mPage;
     KDFWidget *mKdf;
     KDFConfigWidget *mMcw;
     MntConfigWidget *mKcw;
