@@ -1,6 +1,6 @@
   /*
 
-    $Id: kedit.cpp,v 1.165.2.1 2003/01/31 03:01:55 mueller Exp $
+    $Id: kedit.cpp,v 1.165.2.6 2003/06/30 23:49:33 aseigo Exp $
 
     Copyright (C) 1997 Bernd Johannes Wuebben
                        wuebben@math.cornell.edu
@@ -108,6 +108,7 @@ TopLevel::~TopLevel ()
 void TopLevel::setupEditWidget()
 {
   eframe = new KEdit (this, "eframe");
+  eframe->setOverwriteEnabled(true);
   KCursor::setAutoHideCursor( eframe, true );
 
   connect(eframe, SIGNAL(CursorPositionChanged()),this,
@@ -126,6 +127,8 @@ void TopLevel::setupEditWidget()
 	  SLOT(setEnabled(bool)));
   connect( eframe, SIGNAL(selectionChanged()),this,
      SLOT(slotSelectionChanged()));
+  connect( eframe, SIGNAL(modificationChanged( bool)),
+           SLOT(setFileCaption()));
 
 
   undoAction->setEnabled(false);
@@ -281,7 +284,6 @@ void TopLevel::saveProperties(KConfig* config)
 
 
 void TopLevel::readProperties(KConfig* config){
-
     KURL url = config->readEntry("url");
     QString filename = config->readEntry("saved_to");
 
@@ -289,31 +291,33 @@ void TopLevel::readProperties(KConfig* config){
     int modified = config->readNumEntry("modified",0);
     int line = config->readNumEntry("current_line", 0);
     int col = config->readNumEntry("current_column", 0);
+    int result = KEDIT_RETRY;
 
-    if(!filename.isEmpty() && modified){
-	int result = openFile(filename, OPEN_READWRITE, url.fileEncoding());
-        if (result == KEDIT_OK)
+    if(!filename.isEmpty())
+    {
+        if (modified)
         {
-	  m_url = url;
-	  eframe->setModified(TRUE);
-          eframe->setCursorPosition(line, col);
-	  setFileCaption();
-          statusbar_slot();
-	}
-    }
-    else{
-
-      if(!filename.isEmpty()){
-	int result = openFile(filename, OPEN_READWRITE, url.fileEncoding());
-        if (result == KEDIT_OK)
-        {
-          m_url = url;
-          eframe->setModified(false);
-          eframe->setCursorPosition(line, col);
-          setFileCaption();
-          statusbar_slot();
+            result = openFile(filename, OPEN_READWRITE, url.fileEncoding());
         }
-      }
+        else
+        {
+            result = openFile(filename, OPEN_READWRITE, url.fileEncoding());
+        }
+    }
+    else
+    {
+        openURL(url, OPEN_READWRITE);
+        modified = false;
+        result = KEDIT_OK;
+    }
+
+    if (result == KEDIT_OK)
+    {
+        m_url = url;
+        eframe->setModified(modified);
+        eframe->setCursorPosition(line, col);
+        setFileCaption();
+        statusbar_slot();
     }
 }
 
@@ -384,7 +388,6 @@ void TopLevel::file_new()
 
 void TopLevel::clean_space()
 {
-   if (!eframe);
    eframe->cleanWhiteSpace();
 }
 
@@ -939,7 +942,7 @@ void TopLevel::setFileCaption()
      if (!encoding.isEmpty())
         m_caption += QString(" (%1)").arg(encoding);
   }
-  setCaption(m_caption);
+  setCaption(m_caption, eframe->isModified());
 }
 
 
@@ -1076,6 +1079,7 @@ void TopLevel::save_options()
   KConfig *config = kapp->config();
   config->setGroup("MainWindow");
   saveMainWindowSettings(config);
+  config->sync();
 }
 
 int TopLevel::saveURL( const KURL& _url )
