@@ -40,7 +40,7 @@ static const QStringList &operationStrings( void );
 
 
 CGotoDialog::CGotoDialog( QWidget *parent, const char *name, bool modal )
-  :KDialogBase( Plain, i18n("Goto Offset"), Ok|Cancel, Ok, parent, name, 
+  :KDialogBase( Plain, i18n("Goto Offset"), Ok|Cancel, Ok, parent, name,
 		modal )
 {
   QVBoxLayout *topLayout = new QVBoxLayout( plainPage(), 0, spacingHint() );
@@ -56,7 +56,7 @@ CGotoDialog::CGotoDialog( QWidget *parent, const char *name, bool modal )
   mComboBox->setInsertionPolicy( QComboBox::AtTop );  
   mComboBox->setMinimumWidth( fontMetrics().maxWidth()*17 );
 
-  QLabel *label = new QLabel( mComboBox, i18n("O&ffset"), plainPage() );
+  QLabel *label = new QLabel( mComboBox, i18n("O&ffset:"), plainPage() );
   if( label == 0 ) { return; }
 
   vbox->addWidget( label );
@@ -190,7 +190,7 @@ CFindDialog::CFindDialog( QWidget *parent, const char *name, bool modal )
   mSelector->insertStringList( formatStrings() );
   connect( mSelector, SIGNAL(activated(int)), SLOT(selectorChanged(int)) );
  
-  QLabel *label = new QLabel( mSelector, i18n("Fo&rmat"), plainPage() );
+  QLabel *label = new QLabel( mSelector, i18n("Fo&rmat:"), plainPage() );
   if( label == 0 ) { return; }
 
   vbox->addWidget( label );
@@ -205,7 +205,7 @@ CFindDialog::CFindDialog( QWidget *parent, const char *name, bool modal )
   if( mFindValidator == 0 ) { return; }
   mInput->setValidator( mFindValidator );
 
-  label = new QLabel( mInput, i18n("F&ind"), plainPage() );
+  label = new QLabel( mInput, i18n("F&ind:"), plainPage() );
   if( label == 0 ) { return; }
 
   vbox->addWidget( label );
@@ -350,8 +350,8 @@ void CFindDialog::findAgain( EOperation operation )
 
 CFindNavigatorDialog::CFindNavigatorDialog( QWidget *parent, const char *name,
 					     bool modal )
-  :KDialogBase( Plain, i18n("Find (Navigator)"), User3|User2|User1|Close, 
-		User2, parent, name, modal, true, i18n("New &key"), 
+  :KDialogBase( Plain, i18n("Find (Navigator)"), User3|User2|User1|Close,
+		User2, parent, name, modal, true, i18n("New &Key"),
 		i18n("&Next"), i18n("&Previous") )
 {
   QString text;
@@ -487,7 +487,7 @@ void CFindNavigatorDialog::done( int resultCode )
 
 
 CReplaceDialog::CReplaceDialog( QWidget *parent, const char *name, bool modal )
-  :KDialogBase( Plain, i18n("Find and Replace"), Ok|Cancel, Ok, 
+  :KDialogBase( Plain, i18n("Find and Replace"), Ok|Cancel, Ok,
 		parent, name, modal )
 {
   QString text;
@@ -506,7 +506,7 @@ CReplaceDialog::CReplaceDialog( QWidget *parent, const char *name, bool modal )
   connect( mFindSelector, SIGNAL(activated(int)), 
 	   SLOT(findSelectorChanged(int)) );
   
-  text = i18n("Fo&rmat (find)");
+  text = i18n("Fo&rmat (find):");
   QLabel *label = new QLabel( mFindSelector, text, plainPage() );
   if( label == 0 ) { return; }
 
@@ -522,7 +522,7 @@ CReplaceDialog::CReplaceDialog( QWidget *parent, const char *name, bool modal )
   connect( mFindInput, SIGNAL(textChanged(const QString&)), 
 	   SLOT(findInputChanged(const QString&)) );
 
-  label = new QLabel( mFindInput, i18n("F&ind"), plainPage() );
+  label = new QLabel( mFindInput, i18n("F&ind:"), plainPage() );
   if( label == 0 ) { return; }
 
   vbox->addWidget( label );
@@ -535,7 +535,7 @@ CReplaceDialog::CReplaceDialog( QWidget *parent, const char *name, bool modal )
   connect( mReplaceSelector, SIGNAL(activated(int)), 
 	   SLOT(replaceSelectorChanged(int)) );
 
-  text = i18n("For&mat (replace)");
+  text = i18n("For&mat (replace):");
   label = new QLabel( mReplaceSelector, text, plainPage() );
   if( label == 0 ) { return; }
   label->setFixedHeight( label->sizeHint().height() );
@@ -552,7 +552,7 @@ CReplaceDialog::CReplaceDialog( QWidget *parent, const char *name, bool modal )
   connect( mReplaceInput, SIGNAL(textChanged(const QString&)), 
 	   SLOT(replaceInputChanged(const QString&)) );
 
-  label = new QLabel( mReplaceInput, i18n("Rep&lace"), plainPage() );
+  label = new QLabel( mReplaceInput, i18n("Rep&lace:"), plainPage() );
   if( label == 0 ) { return; }
   label->setFixedHeight( label->sizeHint().height() );
 
@@ -697,7 +697,7 @@ void CReplaceDialog::slotOk( void )
 
 CReplacePromptDialog::CReplacePromptDialog( QWidget *parent, const char *name,
 					     bool modal )
-  :KDialogBase( Plain, i18n("Find and Replace"), User3|User2|User1|Close, 
+  :KDialogBase( Plain, i18n("Find and Replace"), User3|User2|User1|Close,
 		User2, parent, name, modal, true, i18n("&All"), 
 		i18n("&No"), i18n("&Yes") )
 {
@@ -777,7 +777,7 @@ void CReplacePromptDialog::done( int returnCode )
 
 
 CFilterDialog::CFilterDialog( QWidget *parent, const char *name, bool modal )
-  :KDialogBase( Plain, i18n("Binary Filter"), Ok|Cancel, Ok, 
+  :KDialogBase( Plain, i18n("Binary Filter"), Ok|Cancel, Ok,
 		parent, name, modal )
 {
   QString text;
@@ -796,7 +796,7 @@ CFilterDialog::CFilterDialog( QWidget *parent, const char *name, bool modal )
   connect( mOperationSelector, SIGNAL(activated(int)), 
 	   SLOT(operationSelectorChanged(int)) );
 
-  text = i18n("O&peration");
+  text = i18n("O&peration:");
   QLabel *label = new QLabel( mOperationSelector, text, plainPage() );
   if( label == 0 ) { return; }
 
@@ -871,7 +871,7 @@ void CFilterDialog::makeOperandLayout( void )
   connect( mOperandSelector, SIGNAL(activated(int)), 
 	   SLOT(operandSelectorChanged(int)) );
 
-  text = i18n("Fo&rmat (operand)");
+  text = i18n("Fo&rmat (operand):");
   mOperandFormatLabel = new QLabel( mOperandSelector, text, page );
   if( mOperandFormatLabel == 0 ) { return; }
 
@@ -884,10 +884,10 @@ void CFilterDialog::makeOperandLayout( void )
   mOperandValidator = new CHexValidator( this, CHexValidator::regularText );
   if( mOperandValidator == 0 ) { return; }
   mOperandInput->setValidator( mOperandValidator );
-  connect( mOperandInput, SIGNAL(textChanged(const QString&)), 
+  connect( mOperandInput, SIGNAL(textChanged(const QString&)),
 	   SLOT(operandInputChanged(const QString&)) );
 
-  mOperandInputLabel = new QLabel( mOperandInput, i18n("O&perand"), page );
+  mOperandInputLabel = new QLabel( mOperandInput, i18n("O&perand:"), page );
   if( mOperandInputLabel == 0 ) { return; }
 
   vbox->addWidget( mOperandInputLabel );
@@ -1086,7 +1086,7 @@ void CFilterDialog::operationSelectorChanged( int index )
 
 
 CInsertDialog::CInsertDialog( QWidget *parent, const char *name, bool modal )
-  :KDialogBase( Plain, i18n("Insert Pattern"), Ok|Cancel, Ok, 
+  :KDialogBase( Plain, i18n("Insert Pattern"), Ok|Cancel, Ok,
 		parent, name, modal )
 {
 
@@ -1103,8 +1103,8 @@ CInsertDialog::CInsertDialog( QWidget *parent, const char *name, bool modal )
   mSizeBox->setMinimumWidth( fontMetrics().maxWidth()*17 );
   mSizeBox->setRange( 1, INT_MAX );
   mSizeBox->setValue( 1 );
-  
-  QLabel *label = new QLabel( mSizeBox, i18n("&Size"), plainPage() );
+
+  QLabel *label = new QLabel( mSizeBox, i18n("&Size:"), plainPage() );
   if( label == 0 ) { return; }
 
   vbox->addWidget( label );
@@ -1117,10 +1117,10 @@ CInsertDialog::CInsertDialog( QWidget *parent, const char *name, bool modal )
   connect( mPatternSelector, SIGNAL(activated(int)),
 	   SLOT(patternSelectorChanged(int)) );
 
-  text = i18n("Fo&rmat (pattern)");
+  text = i18n("Fo&rmat (pattern):");
   label = new QLabel( mPatternSelector, text, plainPage() );
   if( label == 0 ) { return; }
- 
+
   vbox->addWidget( label );
   vbox->addWidget( mPatternSelector );
 
@@ -1130,10 +1130,10 @@ CInsertDialog::CInsertDialog( QWidget *parent, const char *name, bool modal )
   mPatternValidator = new CHexValidator( this, CHexValidator::regularText );
   if( mPatternValidator == 0 ) { return; }
   mPatternInput->setValidator( mPatternValidator );
-  connect( mPatternInput, SIGNAL(textChanged(const QString&)), 
+  connect( mPatternInput, SIGNAL(textChanged(const QString&)),
 	   SLOT(patternInputChanged(const QString&)) );
 
-  label = new QLabel( mPatternInput, i18n("&Pattern"), plainPage() );
+  label = new QLabel( mPatternInput, i18n("&Pattern:"), plainPage() );
   if( label == 0 ) { return; }
 
   vbox->addWidget( label );
@@ -1142,7 +1142,7 @@ CInsertDialog::CInsertDialog( QWidget *parent, const char *name, bool modal )
   mOffsetInput = new QLineEdit( plainPage() );
   mOffsetInput->setMinimumWidth( fontMetrics().maxWidth()*17 );
 
-  mOffsetLabel = new QLabel( mOffsetInput, i18n("&Offset"), plainPage() );
+  mOffsetLabel = new QLabel( mOffsetInput, i18n("&Offset:"), plainPage() );
   if( mOffsetLabel == 0 ) { return; }
 
   vbox->addWidget( mOffsetLabel );
@@ -1420,7 +1420,7 @@ static const QStringList &formatStrings( void )
     list.append( i18n( "Decimal" ) );
     list.append( i18n( "Octal" ) );
     list.append( i18n( "Binary" ) );
-    list.append( i18n( "Regular text" ) );
+    list.append( i18n( "Regular Text" ) );
   }
   return( list );
 }
@@ -1438,7 +1438,7 @@ static const QStringList &operationStrings( void )
     list.append( i18n( "REVERSE data" ) );
     list.append( i18n( "ROTATE data" ) );
     list.append( i18n( "SHIFT data" ) );
-    list.append( i18n( "Swap individual bits" ) );
+    list.append( i18n( "Swap Individual Bits" ) );
   }
 
   return( list );
