@@ -22,8 +22,8 @@
 #include <qlabel.h>
 #include <qlayout.h>
 
-#include <kapp.h>
 #include <kglobalsettings.h>
+#include <kglobal.h>
 #include <klocale.h>
 
 #include "fileinfodialog.h"
@@ -154,8 +154,8 @@ void CFileInfoDialog::setStatistics( void ) // Default
 {
   setClean();
   mFrequencyList->clear();
-  mFileNameLabel->setText("");
-  mFileSizeLabel->setText("");
+  mFileNameLabel->clear();
+  mFileSizeLabel->clear();
 
   QString u("?");
   QString d, h, o, b, c;
@@ -195,7 +195,7 @@ void CFileInfoDialog::setStatistics( SStatisticControl &sc )
   setClean();
   mFrequencyList->clear();
   mFileNameLabel->setText( sc.documentName );
-  mFileSizeLabel->setText( QString("%1").arg(sc.documentSize));
+  mFileSizeLabel->setText( KGlobal::locale()->formatNumber(sc.documentSize, 0) );
 
   QString d, h, o, b, c, n, p;
   QListViewItem *item = 0;
@@ -316,3 +316,4 @@ void CFileInfoDialog::timerEvent( QTimerEvent * )
 
 
 
+#include "fileinfodialog.moc"
