@@ -37,7 +37,7 @@
 #include <qstring.h>
 #include <qtextstream.h>
 
-#include "kapp.h"
+#include <kapplication.h>
 
 #include "conversion.h"
 #include "hexeditstate.h"
