@@ -18,8 +18,6 @@
  *
  */
 
-#include <kglobal.h>
-#include <kiconloader.h>
 
 #include "hexdrag.h"
 static const char *mediaString = "application/octet-stream";
