@@ -63,12 +63,6 @@ void CHexPrinter::setRange( bool state, uint start, uint stop )
 }
 
 
-void CHexPrinter::setOutputToStdout( bool state )
-{
-  mOutputToStdout = state;
-}
-
-
 void CHexPrinter::setScaleToFit( bool state )
 {
   mScaleToFit = state;
