@@ -50,7 +50,7 @@ int main( int argc, char **argv )
     version, description, KAboutData::License_GPL_V2,
     "(c) 1999-2000, Espen Sand");
   aboutData.addAuthor("Espen Sand",0, "espensa@online.no",
-		      "http://home.sol.no/~espensa/khexedit/" );
+		      "http://home.online.no/~espensa/khexedit/" );
   aboutData.addCredit("",I18N_NOOP("\n"
     "This program uses modified code and techniques from other KDE programs,\n"
     "specifically kwrite, kiconedit and ksysv. Credit goes to authors\n"
