@@ -94,7 +94,7 @@ void COptionDialog::showEvent( QShowEvent *e )
 void COptionDialog::setupLayoutPage( void )
 {
   QString text;
-  QFrame *page = addPage( i18n("Layout"), i18n("Data layout in editor"),
+  QFrame *page = addPage( i18n("Layout"), i18n("Data Layout in Editor"),
 			  BarIcon("khexedit", KIcon::SizeMedium ) );
 
   QGridLayout *gbox = new QGridLayout( page, 15, 2, 0, spacingHint() );
@@ -102,11 +102,11 @@ void COptionDialog::setupLayoutPage( void )
 
   mLayout.formatCombo  = new QComboBox( false, page );
   QStringList modeList;
-  modeList.append( i18n("Hexadecimal mode") );
-  modeList.append( i18n("Decimal mode") );
-  modeList.append( i18n("Octal mode") );
-  modeList.append( i18n("Binary mode") );
-  modeList.append( i18n("Text only mode") );
+  modeList.append( i18n("Hexadecimal Mode") );
+  modeList.append( i18n("Decimal Mode") );
+  modeList.append( i18n("Octal Mode") );
+  modeList.append( i18n("Binary Mode") );
+  modeList.append( i18n("Text Only Mode") );
   mLayout.formatCombo->insertStringList( modeList );
   connect( mLayout.formatCombo, SIGNAL(activated(int)),
 	   SLOT(slotModeSelectorChanged(int)) );
@@ -129,11 +129,11 @@ void COptionDialog::setupLayoutPage( void )
 	   SLOT(slotColumnSizeChanged(int) ) );
   gbox->addWidget( mLayout.columnSizeSpin, 2, 1 );
 
-  text = i18n("Default l&ine size [bytes]");
+  text = i18n("Default l&ine size [bytes]:");
   QLabel *label = new QLabel( mLayout.lineSizeSpin, text, page );
   gbox->addWidget( label, 1, 0 );
 
-  text = i18n("Colu&mn size [bytes]");
+  text = i18n("Colu&mn size [bytes]:");
   label = new QLabel( mLayout.columnSizeSpin, text, page );
   gbox->addWidget( label, 2, 0 );
 
@@ -145,7 +145,7 @@ void COptionDialog::setupLayoutPage( void )
   mLayout.lockLineCheck = new QCheckBox( text, page );
   gbox->addMultiCellWidget( mLayout.lockLineCheck, 4, 4, 0, 1, AlignLeft );
 
-  text = i18n("Loc&k column at end of line (when column size > 1)");
+  text = i18n("Loc&k column at end of line (when column size>1)");
   mLayout.lockColumnCheck = new QCheckBox( text, page );
   gbox->addMultiCellWidget( mLayout.lockColumnCheck, 5, 5, 0, 1 );
 
@@ -155,14 +155,14 @@ void COptionDialog::setupLayoutPage( void )
 
   QStringList gridList;
   gridList.append( i18n("None") );
-  gridList.append( i18n("Vertical only") );
-  gridList.append( i18n("Horizontal only") );
-  gridList.append( i18n("Both directions") );
+  gridList.append( i18n("Vertical Only") );
+  gridList.append( i18n("Horizontal Only") );
+  gridList.append( i18n("Both Directions") );
 
   mLayout.gridCombo = new QComboBox( false, page );
   mLayout.gridCombo->insertStringList( gridList );
 
-  text = i18n("&Gridlines between text");
+  text = i18n("&Gridlines between text:");
   label = new QLabel( mLayout.gridCombo, text, page );
 
   gbox->addWidget( label, 7, 0 );
@@ -176,11 +176,11 @@ void COptionDialog::setupLayoutPage( void )
   mLayout.rightSepWidthSpin->setRange( 0, 20 );
   gbox->addWidget( mLayout.rightSepWidthSpin, 9, 1 );
 
-  text = i18n("&Left separator width [pixels]");
+  text = i18n("&Left separator width [pixels]:");
   mLayout.leftSepLabel = new QLabel( mLayout.leftSepWidthSpin, text, page );
   gbox->addWidget( mLayout.leftSepLabel, 8, 0 );
 
-  text = i18n("&Right separator width [pixels]");
+  text = i18n("&Right separator width [pixels]:");
   mLayout.rightSepLabel = new QLabel( mLayout.rightSepWidthSpin, text, page );
   gbox->addWidget( mLayout.rightSepLabel, 9, 0 );
 
@@ -192,11 +192,11 @@ void COptionDialog::setupLayoutPage( void )
   mLayout.edgeSpin->setRange( 0, 20 );
   gbox->addWidget( mLayout.edgeSpin, 11, 1 );
 
-  text = i18n("&Separator margin width [pixels]");
+  text = i18n("&Separator margin width [pixels]:");
   label = new QLabel( mLayout.separatorSpin, text, page );
   gbox->addWidget( label, 10, 0 );
 
-  text = i18n("&Edge margin width [pixels]");
+  text = i18n("&Edge margin width [pixels]:");
   label = new QLabel( mLayout.edgeSpin, text, page );
   gbox->addWidget( label, 11, 0 );
 
@@ -209,7 +209,7 @@ void COptionDialog::setupLayoutPage( void )
   mLayout.columnSepSpin = new QSpinBox( page );
   mLayout.columnSepSpin->setRange( 1, 100 );
 
-  text = i18n("Column separa&tion [pixels]");
+  text = i18n("Column separa&tion [pixels]:");
   mLayout.columnSepLabel = new QLabel( mLayout.columnSepSpin, text, page );
 
   gbox->addWidget( mLayout.columnSepLabel, 13, 0 );
@@ -223,7 +223,7 @@ void COptionDialog::setupCursorPage( void )
 {
   QString text;
   QFrame *page = addPage( i18n("Cursor"),
-    i18n("Cursor behavior. Only valid for editor"),
+    i18n("Cursor Behavior (only valid for editor)"),
     BarIcon("mouse", KIcon::SizeMedium ) );
   QVBoxLayout *topLayout = new QVBoxLayout( page, 0, spacingHint() );
 
@@ -237,7 +237,7 @@ void COptionDialog::setupCursorPage( void )
 	   SLOT( slotBlinkIntervalCheck(bool)));
 
   QHBox *hbox = new QHBox( group );
-  mCursor.blinkLabel = new QLabel( i18n("&Blink interval [ms]" ), hbox );
+  mCursor.blinkLabel = new QLabel( i18n("&Blink interval [ms]:" ), hbox );
   mCursor.blinkSpin = new QSpinBox( hbox );
   mCursor.blinkSpin->setMinimumWidth( fontMetrics().width("M") * 10 );
   mCursor.blinkSpin->setRange( 100, 1000 );
@@ -256,7 +256,7 @@ void COptionDialog::setupCursorPage( void )
   text = i18n("Use &thick cursor in insert mode");
   mCursor.thickCheck = new QCheckBox( text, group );
 
-  text = i18n("Cursor behavior when editor looses focus");
+  text = i18n("Cursor Behavior When Editor Loses Focus");
   group = new QVButtonGroup( text, page );
   group->layout()->setMargin( spacingHint() );
   topLayout->addWidget( group );
@@ -275,7 +275,7 @@ void COptionDialog::setupColorPage( void )
 {
   QString text;
   QFrame *page = addPage( i18n("Colors"),
-    i18n("Editor colors. System selection color is always used"),
+    i18n("Editor Colors (system selection color is always used)"),
     BarIcon("colorize", KIcon::SizeMedium ) );
 
   QVBoxLayout *topLayout = new QVBoxLayout( page, 0, spacingHint() );
@@ -324,7 +324,7 @@ void COptionDialog::setupFontPage( void )
 {
   QString text;
   QFrame *page = addPage( i18n("Font"),
-    i18n("Font selection. Editor can only use a fixed font"),
+    i18n("Font Selection (editor can only use a fixed font)"),
     BarIcon("fonts", KIcon::SizeMedium ) );
 
   QVBoxLayout *topLayout = new QVBoxLayout( page, 0, spacingHint() );
@@ -368,7 +368,7 @@ void COptionDialog::setupFontPage( void )
 void COptionDialog::setupFilePage( void )
 {
   QString text;
-  QFrame *page = addPage( i18n("Files"), i18n("File management"),
+  QFrame *page = addPage( i18n("Files"), i18n("File Management"),
 			  BarIcon("kmultiple", KIcon::SizeMedium ) );
 
   QVBoxLayout *topLayout = new QVBoxLayout( page, 0, spacingHint() );
@@ -379,12 +379,12 @@ void COptionDialog::setupFilePage( void )
   mFile.openCombo = new QComboBox( false, page );
   QStringList modeList;
   modeList.append( i18n("None") );
-  modeList.append( i18n("Most recent document") );
-  modeList.append( i18n("All recent documents") );
+  modeList.append( i18n("Most Recent Document") );
+  modeList.append( i18n("All Recent Documents") );
   mFile.openCombo->insertStringList( modeList );
   mFile.openCombo->setMinimumWidth( mFile.openCombo->sizeHint().width() );
 
-  text = i18n("Open doc&uments on startup");
+  text = i18n("Open doc&uments on startup:");
   QLabel *label = new QLabel( mFile.openCombo, text, page );
 
   gbox->addWidget( label, 0, 0 );
@@ -418,7 +418,7 @@ void COptionDialog::setupFilePage( void )
   mFile.discardRecentCheck = new QCheckBox( text, page );
   topLayout->addWidget( mFile.discardRecentCheck, 0, AlignLeft );
 
-  text = i18n("Clear \"Recent\" Document List &Now");
+  text = i18n("Cl&ear \"Recent\" Document List");
   QPushButton *discardRecentButton = new QPushButton( page );
   discardRecentButton->setText( text );
   topLayout->addWidget( discardRecentButton, 0, AlignCenter );
@@ -435,7 +435,7 @@ void COptionDialog::setupMiscPage( void )
   QString text;
   QLabel *label;
 
-  QFrame *page = addPage( i18n("Miscellaneous"), i18n("Various properties"),
+  QFrame *page = addPage( i18n("Miscellaneous"), i18n("Various Properties"),
 			  BarIcon("gear", KIcon::SizeMedium ) );
 
   QVBoxLayout *topLayout = new QVBoxLayout( page, 0, spacingHint() );
@@ -465,7 +465,7 @@ void COptionDialog::setupMiscPage( void )
   text = i18n("Make sound on &fatal failure");
   mMisc.fatalCheck = new QCheckBox( text, group );
 
-  group = new QVButtonGroup( i18n("Bookmark visibility"), page );
+  group = new QVButtonGroup( i18n("Bookmark Visibility"), page );
   group->layout()->setMargin( spacingHint() );
   topLayout->addWidget( group );
   text = i18n("Use visible bookmarks in the offset column");
@@ -489,7 +489,7 @@ void COptionDialog::setupMiscPage( void )
   mMisc.thresholdSpin->setSteps( 5, 5 );
   mMisc.thresholdSpin->setValue( 5 );
 
-  text = i18n("&Threshold [pages]" );
+  text = i18n("&Threshold [pages]:" );
   mMisc.thresholdLabel = new QLabel( mMisc.thresholdSpin, text, page );
 
   glay->addWidget( mMisc.thresholdLabel, 0, 0 );
@@ -504,7 +504,7 @@ void COptionDialog::setupMiscPage( void )
   mMisc.undoSpin->setSteps( 5, 5 );
   mMisc.undoSpin->setValue( 50 );
 
-  label = new QLabel( mMisc.undoSpin, i18n("&Undo limit"), page );
+  label = new QLabel( mMisc.undoSpin, i18n("&Undo limit:"), page );
   glay->addWidget( label, 2, 0 );
   glay->addWidget( mMisc.undoSpin, 2, 1 );
 
