@@ -198,7 +198,7 @@ void CStringDialog::slotUser1( void ) // Start
       "The filter expression you have specified is illegal. "
       "You must specify a valid regular expression.\n"
       "Continue without filter?");
-    int reply = KMessageBox::warningContinueCancel( this, msg, i18n("Extract strings"));
+    int reply = KMessageBox::warningContinueCancel( this, msg, i18n("Extract Strings"));
     if( reply != KMessageBox::Continue )
     {
       return;
