@@ -25,7 +25,7 @@
 #include <config.h>
 #endif
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <kstdaccel.h>
 #include <kmainwindow.h>
 
@@ -41,7 +41,6 @@ class KRadioAction;
 class KSelectAction;
 class KToggleAction;
 class KToolBarButton;
-class CAboutKHexEdit;
 class CDragLabel;
 
 
@@ -206,8 +205,6 @@ class KHexEdit : public KMainWindow
     void setEncoding( void );
     void documentMenuCB( int id );
    
-    void showAboutApplication( void );
-
   protected:
     virtual bool queryExit( void );
     virtual bool queryClose( void );
@@ -264,7 +261,6 @@ class KHexEdit : public KMainWindow
     
     CDragLabel     *mDragLabel;
     KToolBarButton *mWriteProtectButton;
-    CAboutKHexEdit *mAboutKHexEdit;
 
     bool mIsModified;
     bool mShowToolBar;
