@@ -252,7 +252,6 @@ KJotsMain::KJotsMain(const char* name)
   connect( s_bar, SIGNAL(valueChanged(int)), this, SLOT(barMoved(int)) );
 
   me_text = new MyMultiEdit( f_text, "me_text" );
-  me_text->setMinimumWidth( fontMetrics().maxWidth()*40 );
   me_text->setFocusPolicy(QWidget::StrongFocus);
   me_text->setEnabled(false);
   
@@ -357,7 +356,7 @@ KJotsMain::KJotsMain(const char* name)
       continue;
     }
     
-    QString decodedFilename = QFile::decodeName((*it).utf8());
+    QString decodedFilename = QFile::decodeName((*it).latin1());
     folder_list.push_back(decodedFilename);
     folders_menu->insertItem(decodedFilename, unique_id);
     if(hotlist.contains(decodedFilename))
@@ -524,7 +523,7 @@ KJotsMain::KJotsMain(const char* name)
   menuBar()->insertSeparator();
   menuBar()->insertItem( i18n("&Help"), helpMenu() );
 
-  int nr = folder_list.findIndex(QFile::decodeName(config->readEntry("LastOpenFolder").utf8()));
+  int nr = folder_list.findIndex(QFile::decodeName(config->readEntry("LastOpenFolder").latin1()));
   if( nr >= 0 )
   {
     openFolder(nr);
