@@ -120,7 +120,6 @@ cs_status_t status;
 fd_set rfds;
 int rc;
 event_t event;
-int thisEvent;  // thisEvent is the index of event in event_tag
 struct stat sb;
 config_info_t cfg;
 KPCMCIACard oldValues(*this);
@@ -139,6 +138,7 @@ tv.tv_sec = 0;  tv.tv_usec = 0;
      if (rc > 0) {
         rc = read(_fd, (void *)&event, 4);
         if (rc == 4) {
+	   int thisEvent = -1;  // thisEvent is the index of event in event_tag
            for (unsigned int j = 0; j < NTAGS; j++) {
               if (event_tag[j].event == event) {
                  thisEvent = j;
