@@ -9,7 +9,7 @@
  *
  * This file contains the implementation of the main laptop battery monitoring daemon
  *
- * $Id: laptop_daemon.cpp,v 1.21 2001/12/13 06:53:49 staikos Exp $
+ * $Id: laptop_daemon.cpp,v 1.25 2002/09/28 22:48:10 deller Exp $
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -255,6 +255,7 @@ void laptop_daemon::dock_quit()
 
 void laptop_daemon::updatePCMCIA(int num)
 {
+  Q_UNUSED(num);
   //kdDebug() << "PCMCIA card " << num << " was updated." << endl;
 
   // Two things we do here.  We provide notifications for cards
@@ -453,12 +454,14 @@ int main(int argc, char **argv)
 void laptop_daemon::displayPixmap()
 {
 	if (have_time == 2 && exists && !powered) {		// in some circumstances
-		KConfig *config = new KConfig("kcmlaptoprc");
-		config->setGroup("BatteryLow");			// we can;t figure this out 'till
 		have_time = (val < 0 ? 0 : 1);			// the battery is not charging
-		config->writeEntry("HaveTime", have_time);
-		config->sync();
-		delete config;
+		KConfig *config = new KConfig("kcmlaptoprc");
+		if (config) {
+			config->setGroup("BatteryLow");			// we can;t figure this out 'till
+			config->writeEntry("HaveTime", have_time);
+			config->sync();
+			delete config;
+		}
 	}
 
 	if (dock_widget)
