@@ -1,7 +1,7 @@
 /*
  * portable.cpp
  *
- * $Id: portable.cpp,v 1.30.2.3 2002/12/06 15:13:05 lunakl Exp $
+ * $Id: portable.cpp,v 1.30.2.4 2003/02/21 16:19:45 staikos Exp $
  *
  * Copyright (c) 1999 Paul Campbell <paul@taniwha.com>
  *
@@ -137,6 +137,8 @@ static char acpi_batt_status1[NAME_MAX+50];
 static char acpi_batt_status2[NAME_MAX+50];
 static char acpi_batt_status3[NAME_MAX+50];
 static char *acpi_batt_info[MAX_BATTERIES] = {acpi_batt_info0, acpi_batt_info1, acpi_batt_info2, acpi_batt_info3};
+static int acpi_batt_dc[MAX_BATTERIES];
+static int acpi_batt_lf[MAX_BATTERIES];
 static char *acpi_batt_status[MAX_BATTERIES] = {acpi_batt_status0, acpi_batt_status1, acpi_batt_status2, acpi_batt_status3};
 
 
@@ -253,6 +255,7 @@ acpi_read(apm_info *ap)
 	int	v, i;
 	int rate, part, total; 
 	int ret = 1;
+	static int locked= 0;
 	char buff[1024];
 	FILE *f;
 
@@ -265,11 +268,13 @@ acpi_read(apm_info *ap)
 		int cap = 0;
 		int first=1;
 
-		if (acpi_batt_info[i][0]) {
-			f = fopen(acpi_batt_info[i], "r");
-		} else {
-			f = 0;
-		}
+		if (!locked){
+			if (acpi_batt_info[i][0]) {
+				f = fopen(acpi_batt_info[i], "r");
+			} else {
+				f = 0;
+			}
+		} else f = 0;
 again:
 		if (f == NULL) {
 			if (!first || !acpi_batt_status[i][0])
@@ -283,7 +288,7 @@ again:
 				break;
 			if (strstr(buff, "Design Capacity Low:") != NULL ||
 			    strstr(buff, "design capacity low:") != NULL) {
-				caplow = getint(buff);
+				acpi_batt_dc[i]= getint(buff);
 			} else
 			if (strstr(buff, "Present Rate:") != NULL ||
 			    strstr(buff, "present rate:") != NULL) {
@@ -294,7 +299,7 @@ again:
 			} else
 			if (strstr(buff, "Last Full Capacity:") != NULL ||
 			    strstr(buff, "last full capacity:") != NULL) {
-				cap = getint(buff);
+				acpi_batt_lf[i] = getint(buff);
 			} else
 			if (strstr(buff, "Remaining Capacity:") != NULL ||
 			    strstr(buff, "remaining capacity:") != NULL) {
@@ -302,6 +307,9 @@ again:
 			} 
 		}
    		fclose(f);
+		caplow = acpi_batt_dc[i];
+		cap = acpi_batt_lf[i];
+
 		if (first && acpi_batt_status[i][0]) {
 			first = 0;
 			f = fopen(acpi_batt_status[i], "r");
@@ -369,6 +377,7 @@ again:
 	}
 	ap->battery_percentage = (total==0?0:100*part/total);
 	ap->apm_flags = 0;
+	locked= 1;
 	return(ret);
 }
 
